NoiseGenerator

Struct NoiseGenerator 

pub struct NoiseGenerator<T: Transcendental> { /* private fields */ }
Coloured noise generator (white, pink, brown, blue, violet).

Uses a Xorshift RNG for the white noise source and applies filtering / integration for the coloured variants.

Implementations

Source

impl<T: Transcendental> NoiseGenerator<T>

pub fn new(noise_type: NoiseType, amplitude: T) -> Self

Create a new noise generator with the given colour and amplitude.